Changelog
=========


<h2><a href="https://github.com/flypipe/sparkleframe/tree/release/0.3.4" target="_blank" rel="noopener noreferrer">release/0.3.4</a></h2>

* <a href="https://github.com/flypipe/sparkleframe/issues/68" target="_blank" rel="noopener noreferrer">68 improve changelog and workflows</a>

<h2><a href="https://github.com/flypipe/sparkleframe/tree/release/0.3.3" target="_blank" rel="noopener noreferrer">release/0.3.3</a></h2>

* <a href="https://github.com/flypipe/sparkleframe/issues/68" target="_blank" rel="noopener noreferrer">68 improve changelog and workflows</a>

<h2><a href="https://github.com/flypipe/sparkleframe/tree/release/0.3.2" target="_blank" rel="noopener noreferrer">release/0.3.2</a></h2>

* <a href="https://github.com/flypipe/sparkleframe/issues/65" target="_blank" rel="noopener noreferrer">65 fix changelog</a>

<h2><a href="https://github.com/flypipe/sparkleframe/tree/release/0.3.1" target="_blank" rel="noopener noreferrer">release/0.3.1</a></h2>

* <a href="https://github.com/flypipe/sparkleframe/issues/63" target="_blank" rel="noopener noreferrer">63 remove catalog from docs</a>

<h2><a href="https://github.com/flypipe/sparkleframe/tree/release/0.3.0" target="_blank" rel="noopener noreferrer">release/0.3.0</a></h2>

* <a href="https://github.com/flypipe/sparkleframe/issues/61" target="_blank" rel="noopener noreferrer">61 [PYSPARK_API_REQUEST] Implement pyspark.sql.functions.abs</a>

<h2><a href="https://github.com/flypipe/sparkleframe/tree/release/0.2.5" target="_blank" rel="noopener noreferrer">release/0.2.5</a></h2>

* <a href="https://github.com/flypipe/sparkleframe/issues/58" target="_blank" rel="noopener noreferrer">58 roll back to upload pypi</a>

<h2><a href="https://github.com/flypipe/sparkleframe/tree/release/0.2.4" target="_blank" rel="noopener noreferrer">release/0.2.4</a></h2>

* <a href="https://github.com/flypipe/sparkleframe/issues/56" target="_blank" rel="noopener noreferrer">56 fix git fetch</a>

<h2><a href="https://github.com/flypipe/sparkleframe/tree/release/0.2.3" target="_blank" rel="noopener noreferrer">release/0.2.3</a></h2>

* <a href="https://github.com/flypipe/sparkleframe/issues/54" target="_blank" rel="noopener noreferrer">54 add changelog to git</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/52" target="_blank" rel="noopener noreferrer">52 error build spark doc coverage</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/50" target="_blank" rel="noopener noreferrer">50 error deploy docs</a>

<h2><a href="https://github.com/flypipe/sparkleframe/tree/release/0.2.2" target="_blank" rel="noopener noreferrer">release/0.2.2</a></h2>

* <a href="https://github.com/flypipe/sparkleframe/issues/48" target="_blank" rel="noopener noreferrer">48 small fixes</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/46" target="_blank" rel="noopener noreferrer">46 fix mkdocs serve</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/44" target="_blank" rel="noopener noreferrer">44 do not run verification workflow on push</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/42" target="_blank" rel="noopener noreferrer">42 remove header from pip compile</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/39" target="_blank" rel="noopener noreferrer">39 GitAction upload changelog.md as artifact</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/38" target="_blank" rel="noopener noreferrer">38 fix change log artifact</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/31" target="_blank" rel="noopener noreferrer">31 Build Docs</a>

<h2><a href="https://github.com/flypipe/sparkleframe/tree/release/0.2.1" target="_blank" rel="noopener noreferrer">release/0.2.1</a></h2>

* <a href="https://github.com/flypipe/sparkleframe/issues/33" target="_blank" rel="noopener noreferrer">33 Fix import error of functions</a>

<h2><a href="https://github.com/flypipe/sparkleframe/tree/release/0.2.0" target="_blank" rel="noopener noreferrer">release/0.2.0</a></h2>

* <a href="https://github.com/flypipe/sparkleframe/issues/27" target="_blank" rel="noopener noreferrer">27 fix git workflow to create version and changelog from the current branch</a>

<h2><a href="https://github.com/flypipe/sparkleframe/tree/release/0.1.0" target="_blank" rel="noopener noreferrer">release/0.1.0</a></h2>

* <a href="https://github.com/flypipe/sparkleframe/issues/9" target="_blank" rel="noopener noreferrer">9 Implement pyspark.sql.Window (and rank, dense_rank and row_number)</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/27" target="_blank" rel="noopener noreferrer">27 fix git workflow to create version and changelog from the current branch</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/24" target="_blank" rel="noopener noreferrer">24 add support to pyspark.sql.DataFrame.schema</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/22" target="_blank" rel="noopener noreferrer">22 add support to pyspark.pandas.DataFrame.dtypes</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/20" target="_blank" rel="noopener noreferrer">20 add support to pyspark.sql.functions.length</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/18" target="_blank" rel="noopener noreferrer">18 implement pyspark.sql.functions.to_timestamp</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/16" target="_blank" rel="noopener noreferrer">16 show issues in changelog in descending order on issue_id</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/14" target="_blank" rel="noopener noreferrer">14 Update changelog to get changelog from the previous release branch</a>
* <a href="https://github.com/flypipe/sparkleframe/issues/12" target="_blank" rel="noopener noreferrer">12 Implement pyspark.sql.functions.regexp_replace</a>

<h2><a href="https://github.com/flypipe/sparkleframe/tree/release/0.0.2" target="_blank" rel="noopener noreferrer">release/0.0.2</a></h2>

* <a href="https://github.com/flypipe/sparkleframe/issues/10" target="_blank" rel="noopener noreferrer">10 Implement simpleString attribute from data types</a>